==> index_now-1.0.5.tar.gz: index_now/tests/src/Unit/NodeOperationsTest.php <==
<?php

namespace Drupal\Tests\index_now\Unit;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\index_now\NodeOperations;
use Drupal\index_now\Service\IndexNowInterface;
use Drupal\node\Entity\Node;
use Drupal\user\Entity\Role;
use Drupal\Tests\UnitTestCase;
use Drupal\user\RoleStorageInterface;
use Prophecy\Argument;

/**
 * Tests the NodeOperations class.
 *
 * @coversDefaultClass \Drupal\index_now\NodeOperations
 *
 * @group index_now
 */
class NodeOperationsTest extends UnitTestCase {

  const CONFIG_NAME = 'index_now.settings';

  const CONFIG_EXCLUDE_NAME = 'exclude_node_types';

  const PERMISSION = 'access content';

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->configFactory = $this->prophesize(ConfigFactoryInterface::class);
    $this->entityTypeManager = $this->prophesize(EntityTypeManagerInterface::class);
    $this->indexNow = $this->prophesize(IndexNowInterface::class);

    $this->roleStorage = $this->prophesize(RoleStorageInterface::class);
    $this->entityTypeManager
      ->getStorage('user_role')
      ->willReturn($this->roleStorage->reveal());

    $this->nodeOperations = new NodeOperations(
      $this->configFactory->reveal(),
      $this->entityTypeManager->reveal(),
      $this->indexNow->reveal()
    );
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeIsUnpublished() {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(FALSE);

    $this->roleStorage->load(Argument::any())
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->nodeOperations->isIndexable($node->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testUserCantAccessContent() {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(FALSE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->nodeOperations->isIndexable($node->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeTypeIsExcluded() {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->config = $this->prophesize(Config::class);
    $this->config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->willReturn(['foo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($this->config->reveal());

    $node->getType()
      ->ShouldBeCalled()
      ->willReturn('foo');

    $this->assertTrue(!$this->nodeOperations->isIndexable($node->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeIsIndexable() {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->config = $this->prophesize(Config::class);
    $this->config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->willReturn(['foo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($this->config->reveal());

    $node->getType()
      ->ShouldBeCalled()
      ->willReturn('bar');

    $this->assertTrue($this->nodeOperations->isIndexable($node->reveal()));
  }

}

==> index_now-1.0.9.tar.gz: index_now/tests/src/Unit/NodeOperationsTest.php <==
<?php

namespace Drupal\Tests\index_now\Unit;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\index_now\NodeOperations;
use Drupal\index_now\Service\IndexNowInterface;
use Drupal\node\Entity\Node;
use Drupal\Tests\UnitTestCase;
use Drupal\user\Entity\Role;
use Drupal\user\RoleStorageInterface;
use Prophecy\Argument;
use Prophecy\PhpUnit\ProphecyTrait;

/**
 * Tests the NodeOperations class.
 *
 * @coversDefaultClass \Drupal\index_now\NodeOperations
 *
 * @group index_now
 */
class NodeOperationsTest extends UnitTestCase {

  use ProphecyTrait;

  const CONFIG_NAME = 'index_now.settings';

  const CONFIG_EXCLUDE_NAME = 'exclude_node_types';

  const PERMISSION = 'access content';

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $this->configFactory = $this->prophesize(ConfigFactoryInterface::class);
    $this->entityTypeManager = $this->prophesize(EntityTypeManagerInterface::class);
    $this->indexNow = $this->prophesize(IndexNowInterface::class);

    $this->roleStorage = $this->prophesize(RoleStorageInterface::class);
    $this->entityTypeManager
      ->getStorage('user_role')
      ->willReturn($this->roleStorage->reveal());

    $this->nodeOperations = new NodeOperations(
      $this->configFactory->reveal(),
      $this->entityTypeManager->reveal(),
      $this->indexNow->reveal()
    );
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeIsUnpublished(): void {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(FALSE);

    $this->roleStorage->load(Argument::any())
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->nodeOperations->isIndexable($node->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testUserCantAccessContent(): void {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(FALSE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->nodeOperations->isIndexable($node->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeTypeIsExcluded(): void {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->config = $this->prophesize(Config::class);
    $this->config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->willReturn(['foo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($this->config->reveal());

    $node->getType()
      ->ShouldBeCalled()
      ->willReturn('foo');

    $this->assertTrue(!$this->nodeOperations->isIndexable($node->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeIsIndexable(): void {
    $node = $this->prophesize(Node::class);

    $node->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->config = $this->prophesize(Config::class);
    $this->config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->willReturn(['foo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($this->config->reveal());

    $node->getType()
      ->ShouldBeCalled()
      ->willReturn('bar');

    $this->assertTrue($this->nodeOperations->isIndexable($node->reveal()));
  }

}
